/*$Id: s__aux.cc,v 18.17 2000/09/04 09:45:33 al Exp $ -*- C++ -*-
 * aux functions associated with the SIM class
 */
#include "u_status.h"
#include "s__.h"
/*--------------------------------------------------------------------------*/
void SIM::set_limit()
{
  for (int ii = 1;  ii <= STATUS::total_nodes;  ++ii) {
    CKT_BASE::set_limit(v0[ii]);
  }
}
/*--------------------------------------------------------------------------*/
void SIM::keep()
{
  if (!freezetime) {
    for (int ii = 1;  ii <= STATUS::total_nodes;  ++ii) {
      vdc[ii] = v0[ii];
    }
    last_time = (time0 > 0.) ? time0 : 0.;
  }
}
/*--------------------------------------------------------------------------*/
void SIM::restore()
{
  for (int ii = 1;  ii <= STATUS::total_nodes;  ++ii) {
    vt1[ii] = v0[ii] = vdc[ii];
  }
}
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
